#import "IOTConnectSDKSample.h"
#import <IoTConnect/IoTConnectSDK.h>

@interface ViewController ()

@end

@implementation IOTConnectSDKSample {
    IoTConnectSDK *objIoTConnect; // To create IoTConnectSDK object
    
    NSString *cpId;     // CPID
    NSString *uniqueId; // Device UniqueID
    NSString *env;      // Environment
}

- (void)viewDidLoad {
    [super viewDidLoad];
    [self startSDKConnection]; //Start SDK Connection
    // Do any additional setup after loading the view, typically from a nib.
}

#pragma mark - Custom Methods
-(void)startSDKConnection() {
    if(checkValidation()) {
        objIoTConnect = [[IoTConnectSDK alloc] init:cpId :uniqueId :env :^(id message) {
            NSLog(@"Message:%@",message);
            if ([message isKindOfClass:[NSDictionary class]]) {
                if (message[@"sdkStatus"]) {
                    if ([message[@"sdkStatus"] isEqualToString:@"connect"]) {
                        //SDK Connected
                    }else if ([message[@"sdkStatus"] isEqualToString:@"error"]) {
                        //SDK Disconnected
                    }
                } else {
                    NSLog(@"message:%@",message);//Other - Hub To SDK Message
                }
            }
        }];
    }
}

#pragma mark - To Send Data - Need To Call this method
-(void)sendDataToSDK() {
    if (objIoTConnect) {
         NSArray *arrayTPub = @[@{@"uniqueId":uniqueId,
                                @"time":@"<<UTC-Time in format as yyyy-MM-dd'T'HH:mm:ss.SSS'Z'>>",
                                @"data":@{@"temperature":"15.55",
                                          @"humidity":"27.97",
                                          @"gyroscope":@{@"x":"-1.2",@"y":"0.25",@"z":"1.1"
                                          }}}];
         [objIoTConnect SendData:arrayTPub];
    }
}


- (void)showMessage:(NSString *)title withMessage:(NSString *)message {
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:title message:message preferredStyle:UIAlertControllerStyleAlert];
    UIAlertAction *okAction = [UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action){
    }];
    [alert addAction:okAction];
    UIViewController *vc = [[[[UIApplication sharedApplication] delegate] window] rootViewController];
    [vc presentViewController:alert animated:YES completion:nil];
}

#pragma mark - Check Validation
- (bool)checkValidation {
    if([cpId isEqualToString:@""]) {
        [self showMessage:@"" withMessage:@"cpId can not be blank."];
        return false;
    }
    else if([uniqueId isEqualToString:@""]) {
        [self showMessage:@"" withMessage:@"uniqueId can not be blank."];
        return false;
    }
    else if([env isEqualToString:@""]) {
        [self showMessage:@"" withMessage:@"env can not be blank."];
        return false;
    }
    return true;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
